@@ -124,9 +124,9 @@
 #define SBK_QTDATAVISUALIZATION_QABSTRACT3DGRAPH_ELEMENTTYPE_IDX     20
 #define SBK_QTDATAVISUALIZATION_QABSTRACT3DGRAPH_OPTIMIZATIONHINT_IDX 21
 #define SBK_QFLAGS_QTDATAVISUALIZATION_QABSTRACT3DGRAPH_OPTIMIZATIONHINT__IDX 0
-#define SBK_QTDATAVISUALIZATION_Q3DBARS_IDX                          4
 #define SBK_QTDATAVISUALIZATION_Q3DSURFACE_IDX                       12
 #define SBK_QTDATAVISUALIZATION_Q3DSCATTER_IDX                       10
+#define SBK_QTDATAVISUALIZATION_Q3DBARS_IDX                          4
 #define SBK_QTDATAVISUALIZATION_QCUSTOM3DITEM_IDX                    35
 #define SBK_QTDATAVISUALIZATION_QCUSTOM3DVOLUME_IDX                  37
 #define SBK_QTDATAVISUALIZATION_QCUSTOM3DLABEL_IDX                   36
@@ -184,23 +184,24 @@ extern SbkConverter** SbkPySide2_QtDataVisualizationTypeConverters;
 #define SBK_QTDATAVISUALIZATION_QVECTOR_UCHAR_IDX                    4 // QVector<uchar > *
 #define SBK_QTDATAVISUALIZATION_QVECTOR_UNSIGNEDINT_IDX              5 // const QVector<unsigned int > &
 #define SBK_QTDATAVISUALIZATION_QVECTOR_QIMAGEPTR_IDX                6 // const QVector<QImage* > &
-#define SBK_QTDATAVISUALIZATION_QVECTOR_QTDATAVISUALIZATION_QBARDATAITEM_IDX 7 // const QVector<QtDataVisualization::QBarDataItem > *
-#define SBK_QTDATAVISUALIZATION_QVECTOR_QTDATAVISUALIZATION_QSCATTERDATAITEM_IDX 8 // const QVector<QtDataVisualization::QScatterDataItem > &
-#define SBK_QTDATAVISUALIZATION_QVECTOR_FLOAT_IDX                    9 // QVector<float > &
-#define SBK_QTDATAVISUALIZATION_QLIST_QTDATAVISUALIZATION_QCUSTOM3DITEMPTR_IDX 10 // QList<QtDataVisualization::QCustom3DItem* >
-#define SBK_QTDATAVISUALIZATION_QLIST_QTDATAVISUALIZATION_QABSTRACT3DINPUTHANDLERPTR_IDX 11 // QList<QtDataVisualization::QAbstract3DInputHandler* >
-#define SBK_QTDATAVISUALIZATION_QLIST_QTDATAVISUALIZATION_Q3DTHEMEPTR_IDX 12 // QList<QtDataVisualization::Q3DTheme* >
-#define SBK_QTDATAVISUALIZATION_QLIST_QTDATAVISUALIZATION_QABSTRACT3DAXISPTR_IDX 13 // QList<QtDataVisualization::QAbstract3DAxis* >
-#define SBK_QTDATAVISUALIZATION_QLIST_QTDATAVISUALIZATION_QBAR3DSERIESPTR_IDX 14 // QList<QtDataVisualization::QBar3DSeries* >
-#define SBK_QTDATAVISUALIZATION_QLIST_QTDATAVISUALIZATION_QVALUE3DAXISPTR_IDX 15 // QList<QtDataVisualization::QValue3DAxis* >
-#define SBK_QTDATAVISUALIZATION_QLIST_QTDATAVISUALIZATION_QSURFACE3DSERIESPTR_IDX 16 // QList<QtDataVisualization::QSurface3DSeries* >
-#define SBK_QTDATAVISUALIZATION_QLIST_QTDATAVISUALIZATION_QSCATTER3DSERIESPTR_IDX 17 // QList<QtDataVisualization::QScatter3DSeries* >
-#define SBK_QTDATAVISUALIZATION_QLIST_QCOLOR_IDX                     18 // QList<QColor >
-#define SBK_QTDATAVISUALIZATION_QLIST_QLINEARGRADIENT_IDX            19 // QList<QLinearGradient >
-#define SBK_QTDATAVISUALIZATION_QLIST_QVARIANT_IDX                   20 // QList<QVariant >
-#define SBK_QTDATAVISUALIZATION_QLIST_QSTRING_IDX                    21 // QList<QString >
-#define SBK_QTDATAVISUALIZATION_QMAP_QSTRING_QVARIANT_IDX            22 // QMap<QString,QVariant >
-#define SBK_QtDataVisualization_CONVERTERS_IDX_COUNT                 23
+#define SBK_QTDATAVISUALIZATION_QVECTOR_QTDATAVISUALIZATION_QBARDATAITEM_IDX 7 // QVector<QtDataVisualization::QBarDataItem > *
+#define SBK_QTDATAVISUALIZATION_QVECTOR_QTDATAVISUALIZATION_QSURFACEDATAITEM_IDX 8 // QVector<QtDataVisualization::QSurfaceDataItem > *
+#define SBK_QTDATAVISUALIZATION_QVECTOR_QTDATAVISUALIZATION_QSCATTERDATAITEM_IDX 9 // const QVector<QtDataVisualization::QScatterDataItem > &
+#define SBK_QTDATAVISUALIZATION_QVECTOR_FLOAT_IDX                    10 // QVector<float > &
+#define SBK_QTDATAVISUALIZATION_QLIST_QTDATAVISUALIZATION_QCUSTOM3DITEMPTR_IDX 11 // QList<QtDataVisualization::QCustom3DItem* >
+#define SBK_QTDATAVISUALIZATION_QLIST_QTDATAVISUALIZATION_QABSTRACT3DINPUTHANDLERPTR_IDX 12 // QList<QtDataVisualization::QAbstract3DInputHandler* >
+#define SBK_QTDATAVISUALIZATION_QLIST_QTDATAVISUALIZATION_Q3DTHEMEPTR_IDX 13 // QList<QtDataVisualization::Q3DTheme* >
+#define SBK_QTDATAVISUALIZATION_QLIST_QTDATAVISUALIZATION_QABSTRACT3DAXISPTR_IDX 14 // QList<QtDataVisualization::QAbstract3DAxis* >
+#define SBK_QTDATAVISUALIZATION_QLIST_QTDATAVISUALIZATION_QBAR3DSERIESPTR_IDX 15 // QList<QtDataVisualization::QBar3DSeries* >
+#define SBK_QTDATAVISUALIZATION_QLIST_QTDATAVISUALIZATION_QVALUE3DAXISPTR_IDX 16 // QList<QtDataVisualization::QValue3DAxis* >
+#define SBK_QTDATAVISUALIZATION_QLIST_QTDATAVISUALIZATION_QSURFACE3DSERIESPTR_IDX 17 // QList<QtDataVisualization::QSurface3DSeries* >
+#define SBK_QTDATAVISUALIZATION_QLIST_QTDATAVISUALIZATION_QSCATTER3DSERIESPTR_IDX 18 // QList<QtDataVisualization::QScatter3DSeries* >
+#define SBK_QTDATAVISUALIZATION_QLIST_QCOLOR_IDX                     19 // QList<QColor >
+#define SBK_QTDATAVISUALIZATION_QLIST_QLINEARGRADIENT_IDX            20 // QList<QLinearGradient >
+#define SBK_QTDATAVISUALIZATION_QLIST_QVARIANT_IDX                   21 // QList<QVariant >
+#define SBK_QTDATAVISUALIZATION_QLIST_QSTRING_IDX                    22 // QList<QString >
+#define SBK_QTDATAVISUALIZATION_QMAP_QSTRING_QVARIANT_IDX            23 // QMap<QString,QVariant >
+#define SBK_QtDataVisualization_CONVERTERS_IDX_COUNT                 24
 
 // Macros for type check
 
@@ -218,9 +219,9 @@ template<> inline PyTypeObject* SbkType< ::QtDataVisualization::QAbstract3DGraph
 template<> inline PyTypeObject* SbkType< ::QtDataVisualization::QAbstract3DGraph::OptimizationHint >() { return SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QABSTRACT3DGRAPH_OPTIMIZATIONHINT_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QFlags<QtDataVisualization::QAbstract3DGraph::OptimizationHint> >() { return SbkPySide2_QtDataVisualizationTypes[SBK_QFLAGS_QTDATAVISUALIZATION_QABSTRACT3DGRAPH_OPTIMIZATIONHINT__IDX]; }
 template<> inline PyTypeObject* SbkType< ::QtDataVisualization::QAbstract3DGraph >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QABSTRACT3DGRAPH_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QtDataVisualization::Q3DBars >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_Q3DBARS_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QtDataVisualization::Q3DSurface >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_Q3DSURFACE_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QtDataVisualization::Q3DScatter >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_Q3DSCATTER_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QtDataVisualization::Q3DBars >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_Q3DBARS_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QtDataVisualization::QCustom3DItem >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QCUSTOM3DITEM_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QtDataVisualization::QCustom3DVolume >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QCUSTOM3DVOLUME_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QtDataVisualization::QCustom3DLabel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QCUSTOM3DLABEL_IDX]); }
