@@ -59,25 +59,27 @@
 #include <qx11info_x11.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
-#include <QStringList>
 #include <QString>
 #include <signalmanager.h>
+#include <QStringList>
 
 // Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QPair>
-#include <QMap>
-#include <QVector>
-#include <QQueue>
-#include <QSet>
-#include <QLinkedList>
-#include <QMultiMap>
 #include <QStack>
 #include <QList>
+#include <QMap>
+#include <pysideqflags.h>
+#include <QPair>
+#include <QQueue>
+#include <QMultiMap>
+#include <QSet>
+#include <QLinkedList>
+#include <QVector>
 
 // Type indices
-#define SBK_QX11INFO_IDX                                             0
-#define SBK_QtX11Extras_IDX_COUNT                                    1
+#define SBK_QX11INFO_IDX                                             1
+#define SBK_QX11INFO_PEEKOPTION_IDX                                  2
+#define SBK_QFLAGS_QX11INFO_PEEKOPTION__IDX                          0
+#define SBK_QtX11Extras_IDX_COUNT                                    3
 
 // This variable stores all Python types exported by this module.
 extern PyTypeObject** SbkPySide2_QtX11ExtrasTypes;
@@ -97,6 +99,8 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
+template<> inline PyTypeObject* SbkType< ::QX11Info::PeekOption >() { return SbkPySide2_QtX11ExtrasTypes[SBK_QX11INFO_PEEKOPTION_IDX]; }
+template<> inline PyTypeObject* SbkType< ::QFlags<QX11Info::PeekOption> >() { return SbkPySide2_QtX11ExtrasTypes[SBK_QFLAGS_QX11INFO_PEEKOPTION__IDX]; }
 template<> inline PyTypeObject* SbkType< ::QX11Info >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtX11ExtrasTypes[SBK_QX11INFO_IDX]); }
 
 } // namespace Shiboken
